@@ -225,59 +225,22 @@ my $freebsd_logindefs_defaults = {
 };
 
 my $logindefs_dist_map = {
-  'redhat-5.2'      => $rh_logindefs_defaults,
-  'redhat-6.0'      => $rh_logindefs_defaults,
-  'redhat-6.1'      => $rh_logindefs_defaults,
   'redhat-6.2'      => $rh_logindefs_defaults,
   'redhat-7.0'      => $rh_logindefs_defaults,
   'redhat-7.1'      => $rh_logindefs_defaults,
   'redhat-7.2'      => $rh_logindefs_defaults,
   'redhat-7.3'      => $rh_logindefs_defaults,
   'redhat-8.0'      => $rh_logindefs_defaults,
-  'redhat-9'        => $rh_logindefs_defaults,
-  'openna-1.0'      => $rh_logindefs_defaults,
-  'mandrake-7.1'    => $rh_logindefs_defaults,
-  'mandrake-7.2'    => $rh_logindefs_defaults,
   'mandrake-9.0'    => $rh_logindefs_defaults,
-  'mandrake-9.1'    => $rh_logindefs_defaults,
-  'mandrake-9.2'    => $rh_logindefs_defaults,
-  'mandrake-10.0'   => $rh_logindefs_defaults,
-  'mandrake-10.1'   => $rh_logindefs_defaults,
   'pld-1.0'         => $rh_logindefs_defaults,
-  'pld-1.1'         => $rh_logindefs_defaults,
-  'pld-1.99'        => $rh_logindefs_defaults,
   'fedora-1'        => $rh_logindefs_defaults,
-  'fedora-2'        => $rh_logindefs_defaults,
-  'fedora-3'        => $rh_logindefs_defaults,
-  'rpath'           => $rh_logindefs_defaults,
-  'debian-2.2'      => $rh_logindefs_defaults,
   'debian-3.0'      => $rh_logindefs_defaults,
-  'debian-sarge'    => $rh_logindefs_defaults,
-  'ubuntu-5.04'     => $rh_logindefs_defaults,
-  'ubuntu-5.10'     => $rh_logindefs_defaults,
-  'ubuntu-6.04'     => $rh_logindefs_defaults,
   'vine-3.0'        => $rh_logindefs_defaults,
-  'vine-3.1'        => $rh_logindefs_defaults,
   'gentoo'	        => $gentoo_logindefs_defaults,
-  'vlos-1.2'	      => $gentoo_logindefs_defaults,
   'archlinux'       => $gentoo_logindefs_defaults,
   'slackware-9.1.0' => $gentoo_logindefs_defaults,
-  'slackware-10.0.0' => $gentoo_logindefs_defaults,
-  'slackware-10.1.0' => $gentoo_logindefs_defaults,
-  'slackware-10.2.0' => $gentoo_logindefs_defaults,
-  'freebsd-4'       => $freebsd_logindefs_defaults,
   'freebsd-5'       => $freebsd_logindefs_defaults,
-  'freebsd-6'       => $freebsd_logindefs_defaults,
-  'freebsd-7'       => $freebsd_logindefs_defaults,
-  'suse-7.0'        => $gentoo_logindefs_defaults,
   'suse-9.0'        => $gentoo_logindefs_defaults,
-  'suse-9.1'        => $gentoo_logindefs_defaults,
-
-  # FIXME: I don't know about those, so using RH values for now.
-  'turbolinux-7.0'  => $rh_logindefs_defaults,
-  'slackware-8.0.0' => $rh_logindefs_defaults,
-  'slackware-8.1'   => $rh_logindefs_defaults,
-  'slackware-9.0.0' => $rh_logindefs_defaults,
 };
 
 
